@@ -18,6 +18,8 @@ class GUID(TypeDecorator):
     """
     impl = CHAR
 
+    python_type = type(b'')
+
     def load_dialect_impl(self, dialect):
         if dialect.name == 'postgresql':
             return dialect.type_descriptor(UUID())
@@ -40,4 +42,4 @@ class GUID(TypeDecorator):
         if value is None:
             return value
         else:
-            return uuid.UUID(value)
+            return self.python_type(value)
